@@ -1,4 +1,4 @@
-from Column import *
+from .Column import *
 
 class Table:
 	def __init__(self, name):
